@@ -53,26 +53,6 @@ impl XLog {
         }
     }
 
-    // pub fn with_level(mut self, level: LevelFilter) -> XLog {
-    //     self.level = level;
-    //     self
-    // }
-    //
-    // pub fn with_timezone(mut self, timezone: Timezone) -> XLog {
-    //     self.timezone = timezone;
-    //     self
-    // }
-    //
-    // pub fn with_color(mut self, colored: bool) -> XLog {
-    //     self.colored = colored;
-    //     self
-    // }
-    //
-    // pub fn print_level(mut self, print_level: bool) -> XLog {
-    //     self.print_level = print_level;
-    //     self
-    // }
-
     pub fn init(self) -> Result<(), SetLoggerError> {
         log::set_max_level(log::STATIC_MAX_LEVEL);
         log::set_boxed_logger(Box::new(self))?;
@@ -196,7 +176,7 @@ macro_rules! __val {
     )
 }
 
-/// common view
+/// value each line
 #[macro_export]
 macro_rules! val {
     ($v:expr) => {
@@ -219,30 +199,50 @@ macro_rules! val {
     };
 }
 
-/// val format
+/// pretty format
 #[macro_export]
 macro_rules! valf {
     ($v:expr) => {
-        __val!("\n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?}", stringify!($v), $v);
+        __val!("\n{}︎︎︎︎⏤►{:#?}", stringify!($v), $v);
     };
     ($v:expr, $v2:expr) => {
-        __val!("\n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?}", stringify!($v), $v, stringify!($v2), $v2,);
+        __val!("\n{}︎︎︎︎⏤►{:#?} \n{}︎︎︎︎⏤►{:#?}", stringify!($v), $v, stringify!($v2), $v2,);
     };
     ($v:expr, $v2:expr, $v3:expr) => {
-        __val!("\n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3);
+        __val!("\n{}︎︎︎︎⏤►{:#?} \n{}︎︎︎︎⏤►{:#?} \n{}︎︎︎︎⏤►{:#?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3);
     };
     ($v:expr, $v2:expr, $v3:expr, $v4:expr) => {
-        __val!("\n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3, stringify!($v4), $v4);
+        __val!("\n{}︎︎︎︎⏤►{:#?} \n{}︎︎︎︎⏤►{:#?} \n{}︎︎︎︎⏤►{:#?} \n{}︎︎︎︎⏤►{:#?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3, stringify!($v4), $v4);
     };
     ($v:expr, $v2:expr, $v3:expr, $v4:expr, $v5:expr) => {
-        __val!("\n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3, stringify!($v4), $v4, stringify!($v5), $v5);
+        __val!("\n{}︎︎︎︎⏤►{:#?} \n{}︎︎︎︎⏤►{:#?} \n{}︎︎︎︎⏤►{:#?} \n{}︎︎︎︎⏤►{:#?} \n{}︎︎︎︎⏤►{:#?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3, stringify!($v4), $v4, stringify!($v5), $v5);
     };
     ($v:expr, $v2:expr, $v3:expr, $v4:expr, $v5:expr, $v6:expr) => {
-        __val!("\n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3, stringify!($v4), $v4, stringify!($v5), $v5, stringify!($v6), $v6);
+        __val!("\n{}︎︎︎︎⏤►{:#?} \n{}︎︎︎︎⏤►{:#?} \n{}︎︎︎︎⏤►{:#?} \n{}︎︎︎︎⏤►{:#?} \n{}︎︎︎︎⏤►{:#?} \n{}︎︎︎︎⏤►{:#?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3, stringify!($v4), $v4, stringify!($v5), $v5, stringify!($v6), $v6);
     };
 }
+// macro_rules! valf {
+//     ($v:expr) => {
+//         __val!("\n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?}", stringify!($v), $v);
+//     };
+//     ($v:expr, $v2:expr) => {
+//         __val!("\n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?}", stringify!($v), $v, stringify!($v2), $v2,);
+//     };
+//     ($v:expr, $v2:expr, $v3:expr) => {
+//         __val!("\n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3);
+//     };
+//     ($v:expr, $v2:expr, $v3:expr, $v4:expr) => {
+//         __val!("\n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3, stringify!($v4), $v4);
+//     };
+//     ($v:expr, $v2:expr, $v3:expr, $v4:expr, $v5:expr) => {
+//         __val!("\n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3, stringify!($v4), $v4, stringify!($v5), $v5);
+//     };
+//     ($v:expr, $v2:expr, $v3:expr, $v4:expr, $v5:expr, $v6:expr) => {
+//         __val!("\n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3, stringify!($v4), $v4, stringify!($v5), $v5, stringify!($v6), $v6);
+//     };
+// }
 
-// in line
+/// all in one line
 #[macro_export]
 macro_rules! valn {
     ($v:expr) => {
